@@ -5,19 +5,25 @@ use Log::Log4perl;
 use warnings;
 use strict;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 has history          => sub { [] };
 has max_history_size => 10;
 
+my $format_warning_was_shown = 0;
+
 # development notes: Mojo::Log provides 'path' 'handle' and 'format'
 # to handle log location and formatting. Those make no sense in a Log4perl
 # environment (where you can set appenders as you wish) so they are
-# not implemented here.
+# not implemented here; 'format' simply returns the passed-in strings joined by
+# newlines as otherwise Mojo::Log complains (RT #98034).
 sub path   { warn 'path() is not implemented in MojoX::Log::Log4perl. Please use appenders.'   }
 sub handle { warn 'handle() is not implemented in MojoX::Log::Log4perl. Please use appenders.' }
 sub format {
-    warn 'format() is not properly implemented in MojoX::Log::Log4perl. Please use appenders.';
+    if (!$format_warning_was_shown) {
+        $format_warning_was_shown = 1;
+        warn 'format() is not properly implemented in MojoX::Log::Log4perl. Please use appenders.';
+    }
     return sub { '[' . localtime(shift) . '] [' . shift() . '] ' . join("\n", @_, '') };
 }
 
@@ -432,7 +438,7 @@ L<< Log::Log4perl >>, L<< Mojo::Log >>, L<< Mojo >>, L<< Mojolicious >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2014 Breno G. de Oliveira, all rights reserved.
+Copyright 2009-2016 Breno G. de Oliveira, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
